#[non_exhaustive]pub enum ColumnErrorKind {
Missing,
Null,
TypeMismatch {
expected: String,
actual: String,
},
}Expand description
The structured cause of an Error::Column.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Missing
Column name was not found in the result schema.
Null
Column was SQL NULL but the target type was not Option<T>.
TypeMismatch
Column value could not be decoded as the target type.