#[repr(i32)]pub enum TransferMode {
Unspecified = 0,
Async = 1,
Sync = 2,
Adaptive = 3,
}Expand description
The requested result transfer mode.
By default, we recommend using ADAPTIVE for most workloads.
ADAPTIVE and ASYNC are only supported for the ARROW_IPC and
JSON_ARRAY output formats. All other output formats use SYNC mode.
Variants
Unspecified = 0
TRANSFER_MODE_UNSPECIFIED defaults to ADAPTIVE
Async = 1
Only returns the header including the schema and query id. Results need
to be fetched via GetQueryResult. Only supported for JSON_ARRAY and
ARROW_IPC output format.
Sync = 2
All results will be returned with the ExecuteQuery call
Using this mode is discouraged, as there is a 100s timeout.
Adaptive = 3
Returns up to one result chunk synchronously. Subsequent result chunks
may be retrieved via GetQueryResult. If the client does not retrieve
the chunk in time, the server will close the connection. This does not
imply that the query failed. It is the client’s obligation to query the
status or refetch remaining rows from the first chunk in case of
timeouts.
Implementations
Sourceimpl TransferMode
impl TransferMode
Sourceimpl TransferMode
impl TransferMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<TransferMode>
pub fn from_str_name(value: &str) -> Option<TransferMode>
Creates an enum from field names used in the ProtoBuf definition.