MappedInserter

Struct MappedInserter 

pub struct MappedInserter<'conn> { /* private fields */ }
An inserter that supports SQL expression mappings.

This inserter uses a staging table to support computed columns via INSERT…SELECT with SQL expressions. It’s created by Inserter::with_column_mappings.

Implementations

Source

impl<'conn> MappedInserter<'conn>

pub fn add_row(&mut self, values: &[&dyn IntoValue]) -> Result<()>

Adds a row of values to the inserter.

The values should correspond to the columns in the inserter definition, not the target table.

Errors

Forwards the error from Inserter::add_row.

pub fn add_null(&mut self) -> Result<()>

Adds a NULL value.

Errors

Forwards the error from Inserter::add_null.

pub fn add_bool(&mut self, value: bool) -> Result<()>

Adds a boolean value.

Errors

Forwards the error from Inserter::add_bool.

pub fn add_i16(&mut self, value: i16) -> Result<()>

Adds an i16 value.

Errors

Forwards the error from Inserter::add_i16.

pub fn add_i32(&mut self, value: i32) -> Result<()>

Adds an i32 value.

Errors

Forwards the error from Inserter::add_i32.

pub fn add_i64(&mut self, value: i64) -> Result<()>

Adds an i64 value.

Errors

Forwards the error from Inserter::add_i64.

pub fn add_f32(&mut self, value: f32) -> Result<()>

Adds an f32 value.

Errors

Forwards the error from Inserter::add_f32.

pub fn add_f64(&mut self, value: f64) -> Result<()>

Adds an f64 value.

Errors

Forwards the error from Inserter::add_f64.

pub fn add_str(&mut self, value: &str) -> Result<()>

Adds a string value.

Errors

Forwards the error from Inserter::add_str.

pub fn add_bytes(&mut self, value: &[u8]) -> Result<()>

Adds a bytes value.

Errors

Forwards the error from Inserter::add_bytes.

pub fn end_row(&mut self) -> Result<()>

Ends the current row.

Errors

Forwards the error from Inserter::end_row.

pub fn execute(&mut self) -> Result<u64>

Executes the insert with column mappings.

This method:

  1. Inserts all buffered rows into the staging table
  2. Executes INSERT…SELECT from staging to target with mappings
  3. Drops the staging table

Returns the number of rows inserted into the target table.

Errors
  • Returns the error from the inner Inserter::execute if writing the staging rows fails.
  • Returns Error::Client if the INSERT ... SELECT from staging to the target table is rejected (e.g. a mapping expression fails to evaluate).
  • Returns Error::Client if dropping the staging table fails.
pub fn cancel(&mut self)

Cancels the insert and drops the staging table.

This method handles cleanup failures gracefully by logging warnings instead of returning errors. This prevents masking the original error that caused the cancellation.

Logging

Cleanup failures are logged using the tracing crate at WARN level. If tracing is not initialized, errors are written to stderr.