pub struct Time { /* private fields */ }Expand description
A time value (microseconds since midnight).
Implementations
Sourceimpl Time
impl Time
Sourcepub const MICROS_PER_SECOND: u64 = 1_000_000
pub const MICROS_PER_SECOND: u64 = 1_000_000
Microseconds per second
Sourcepub const MICROS_PER_MINUTE: u64
pub const MICROS_PER_MINUTE: u64
Microseconds per minute
Sourcepub const MICROS_PER_HOUR: u64
pub const MICROS_PER_HOUR: u64
Microseconds per hour
Sourcepub const MAX_MICROSECONDS: u64
pub const MAX_MICROSECONDS: u64
Maximum valid microseconds value (24 hours - 1 microsecond).
Sourcepub const fn from_microseconds(microseconds: u64) -> Time
pub const fn from_microseconds(microseconds: u64) -> Time
Creates a Time from microseconds since midnight.
No validation is performed. For a checked variant, use
try_from_microseconds.
Sourcepub fn try_from_microseconds(
microseconds: u64,
) -> Result<Time, Box<dyn Error + Sync + Send>>
pub fn try_from_microseconds( microseconds: u64, ) -> Result<Time, Box<dyn Error + Sync + Send>>
Creates a Time from microseconds since midnight with validation.
Errors
Returns an error if microseconds > MAX_MICROSECONDS
(i.e. >= 24 hours).
Sourcepub const fn new(hour: u32, minute: u32, second: u32, microsecond: u32) -> Time
pub const fn new(hour: u32, minute: u32, second: u32, microsecond: u32) -> Time
Creates a Time from hour, minute, second, microsecond components.
Sourcepub const fn microseconds(&self) -> u64
pub const fn microseconds(&self) -> u64
Returns microseconds since midnight.
Sourcepub const fn to_hms_micro(&self) -> (u32, u32, u32, u32)
pub const fn to_hms_micro(&self) -> (u32, u32, u32, u32)
Returns hour, minute, second, microsecond components.
Sourcepub const fn to_microseconds(&self) -> i64
pub const fn to_microseconds(&self) -> i64
Returns microseconds since midnight as i64 for insertion.
This is the same as microseconds() but as signed for the Inserter API.