FromArrowValue

Trait FromArrowValue 

pub trait FromArrowValue: Sized {
    // Required method
    fn from_arrow_column(array: &Arc<dyn Array>, row: usize) -> Option<Self>;
}
Trait for types that can be extracted from Arrow columns.

Required Methods

fn from_arrow_column(array: &Arc<dyn Array>, row: usize) -> Option<Self>

Extract a value from an Arrow array at the given row index.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl FromArrowValue for bool

Source

fn from_arrow_column(array: &Arc<dyn Array>, row: usize) -> Option<Self>

Source

impl FromArrowValue for f32

Source

fn from_arrow_column(array: &Arc<dyn Array>, row: usize) -> Option<Self>

Source

impl FromArrowValue for f64

Source

fn from_arrow_column(array: &Arc<dyn Array>, row: usize) -> Option<Self>

Source

impl FromArrowValue for i16

Source

fn from_arrow_column(array: &Arc<dyn Array>, row: usize) -> Option<Self>

Source

impl FromArrowValue for i32

Source

fn from_arrow_column(array: &Arc<dyn Array>, row: usize) -> Option<Self>

Source

impl FromArrowValue for i64

Source

fn from_arrow_column(array: &Arc<dyn Array>, row: usize) -> Option<Self>

Source

impl FromArrowValue for String

Source

fn from_arrow_column(array: &Arc<dyn Array>, row: usize) -> Option<Self>

Source

impl FromArrowValue for Vec<u8>

Source

fn from_arrow_column(array: &Arc<dyn Array>, row: usize) -> Option<Self>

Implementors