RowValue

Trait RowValue 

pub trait RowValue: Sized {
    // Required method
    fn from_row(row: &Row, idx: usize) -> Option<Self>;
}
Trait for types that can be extracted from a Row.

Required Methods

fn from_row(row: &Row, idx: usize) -> Option<Self>

Extract a value from a Row at the given column index.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl RowValue for bool

Source

fn from_row(row: &Row, idx: usize) -> Option<Self>

Source

impl RowValue for f32

Source

fn from_row(row: &Row, idx: usize) -> Option<Self>

Source

impl RowValue for f64

Source

fn from_row(row: &Row, idx: usize) -> Option<Self>

Source

impl RowValue for i16

Source

fn from_row(row: &Row, idx: usize) -> Option<Self>

Source

impl RowValue for i32

Source

fn from_row(row: &Row, idx: usize) -> Option<Self>

Source

impl RowValue for i64

Source

fn from_row(row: &Row, idx: usize) -> Option<Self>

Source

impl RowValue for String

Source

fn from_row(row: &Row, idx: usize) -> Option<Self>

Source

impl RowValue for Vec<u8>

Source

fn from_row(row: &Row, idx: usize) -> Option<Self>

Implementors