NoticeReceiver

Type Alias NoticeReceiver 

pub type NoticeReceiver = Box<dyn Fn(Notice) + Sync + Send>;
Type alias for a notice receiver callback.

The callback receives a Notice and is called whenever the server sends a notice or warning message during query execution.

Thread Safety

The callback must be Send + Sync because it may be called from different threads during concurrent query execution.

Aliased Type

pub struct NoticeReceiver(/* private fields */);