pub struct ConnectionManager { /* private fields */ }Expand description
Connection pool manager for AsyncConnection.
The first call to Manager::create holds an async mutex while attempting
to open a connection with the configured CreateMode. Concurrent callers
wait for that attempt to finish, then use CreateMode::DoNotCreate. If the
first attempt fails, the next caller retries with the original create_mode
(for idempotent modes only — Create is not retried because a sibling
connection may have already created the database).
Implementations
Sourceimpl ConnectionManager
impl ConnectionManager
Sourcepub fn new(config: PoolConfig) -> Self
pub fn new(config: PoolConfig) -> Self
Creates a new connection manager.