Pool

Type Alias Pool 

pub type Pool = Pool<ConnectionManager>;
A pool of async connections to a Hyper database.

This pool manages a set of reusable connections, automatically creating new connections when needed and recycling them after use.

Aliased Type

pub struct Pool { /* private fields */ }