pub struct ArrowRow<'a> { /* private fields */ }Expand description
A row from an Arrow record batch, providing typed value access.
Implementations
Sourceimpl<'a> ArrowRow<'a>
impl<'a> ArrowRow<'a>
Sourcepub fn column_count(&self) -> usize
pub fn column_count(&self) -> usize
Returns the number of columns in this row.
Sourcepub fn get<T: FromArrowValue>(&self, col: usize) -> Option<T>
pub fn get<T: FromArrowValue>(&self, col: usize) -> Option<T>
Gets a value at the given column index, with type conversion.
Sourcepub fn get_bool(&self, col: usize) -> Option<bool>
pub fn get_bool(&self, col: usize) -> Option<bool>
Gets a bool value at the given column index.
Sourcepub fn get_string(&self, col: usize) -> Option<String>
pub fn get_string(&self, col: usize) -> Option<String>
Gets a String value at the given column index.