Time

Struct Time 

pub struct Time { /* private fields */ }
A time value (microseconds since midnight).

Implementations

Source

impl Time

pub const MICROS_PER_SECOND: u64 = 1_000_000

Microseconds per second

pub const MICROS_PER_MINUTE: u64

Microseconds per minute

pub const MICROS_PER_HOUR: u64

Microseconds per hour

pub const MAX_MICROSECONDS: u64

Maximum valid microseconds value (24 hours - 1 microsecond).

pub const fn from_microseconds(microseconds: u64) -> Time

Creates a Time from microseconds since midnight.

No validation is performed. For a checked variant, use try_from_microseconds.

pub fn try_from_microseconds( microseconds: u64, ) -> Result<Time, Box<dyn Error + Sync + Send>>

Creates a Time from microseconds since midnight with validation.

Errors

Returns an error if microseconds > MAX_MICROSECONDS (i.e. >= 24 hours).

pub const fn new(hour: u32, minute: u32, second: u32, microsecond: u32) -> Time

Creates a Time from hour, minute, second, microsecond components.

pub const fn microseconds(&self) -> u64

Returns microseconds since midnight.

pub const fn to_hms_micro(&self) -> (u32, u32, u32, u32)

Returns hour, minute, second, microsecond components.

pub const fn encode(&self) -> u64

Returns the raw encoded value.

pub const fn decode(encoded: u64) -> Time

Creates a Time from a raw encoded value.

pub const fn to_microseconds(&self) -> i64

Returns microseconds since midnight as i64 for insertion.

This is the same as microseconds() but as signed for the Inserter API.